==> kara-uc-1.1.16.tgz: package/src/kara-uc/stores/UCFavoriteStore.js <==
import {observable, action, reaction} from 'mobx'


class UCFavorite {
  @observable imgType = ['jpeg', 'gif', 'png', 'jpg', 'bmp']
  @observable favoriteList = 1
  @observable activeTab = 0
  @observable allList ={
    pageSize: 10,
    pageNo: 1,
    result: []
  }
  @observable topicList ={
    pageSize: 10,
    pageNo: 1,
    result: []
  }
  @observable newsList ={
    pageSize: 10,
    pageNo: 1,
    result: []
  }
  @observable messageList ={
    pageSize: 10,
    pageNo: 1,
    result: []
  }
  @observable imgViewList = []


  @action setActiveTab = index => {
    this.activeTab = index
    this.allList ={
      pageSize: 10,
      pageNo: 1,
      result: []
    }
    this.newsList = {
      pageSize: 10,
      pageNo: 1,
      result: []
    }
    this.messageList ={
      pageSize: 10,
      pageNo: 1,
      result: []
    }
    this.topicList ={
      pageSize: 10,
      pageNo: 1,
      result: []
    }
  }
  // @action downLoadFile = (url,fileName) => {
  //   httpAgent.Favorite.downLoadFile(url).then(action(
  //     res => {
  //       saveAs(res, decodeURI(fileName));
  //     }
  //   ))
  // }
  @action getAllList = (res, pageNo) => {
    if(pageNo === 1) {
      this.allList.result = []
    }
    this.allList.pageNo = res.pageInfo.pageNo
    this.allList.pageSize = res.pageInfo.pageSize
    this.allList.pageCount = res.pageInfo.pageCount
    this.allList.result = this.allList.result.concat(res.pageInfo.result)
    res.pageInfo.result.map((i)=>{
      if (this.imgType.includes(i.fileType)) {
        this.imgViewList.push(i)
      }
    })
  }

  @action getTopicList = (res, pageNo) => {
    if(res && res.resultCode && res.resultCode === '000000') {
      if(pageNo === 1) {
        this.topicList.result = []
      }
      this.topicList.pageNo = res.pageInfo.pageNo
      this.topicList.pageSize = res.pageInfo.pageSize
      this.topicList.pageCount = res.pageInfo.pageCount
      this.topicList.result = this.topicList.result.concat(res.pageInfo.result)
    }
  }
  
  @action getNewsList = (res,pageNo) => {
    if(pageNo === 1) {
      this.newsList.result = []
    }
    this.newsList.pageNo = res.pageInfo.pageNo
    this.newsList.pageSize = res.pageInfo.pageSize
    this.newsList.pageCount = res.pageInfo.pageCount
    this.newsList.result = this.newsList.result.concat(res.pageInfo.result)
  }
  
  @action getMessageList = (res,pageNo) => {
    if(pageNo === 1) {
      this.messageList.result = []
    }
    this.messageList.pageNo = res.pageInfo.pageNo
    this.messageList.pageSize = res.pageInfo.pageSize
    this.messageList.pageCount = res.pageInfo.pageCount
    this.messageList.result = this.messageList.result.concat(res.pageInfo.result)
    res.pageInfo.result.map((i)=>{
      if (this.imgType.includes(i.fileType)) {
        this.imgViewList.push(i)
      }
    })
  }
  @action cancelImFavorite = (articleId, cancelType, category) => {
    if(category === 'all'){
      this.allList.result = this.removeItem(this.allList.result,articleId,category, cancelType)
    }else if(category === 'message') {
      this.messageList.result = this.removeItem(this.messageList.result,articleId,category, cancelType)
    }else if(category === 'news') {
      this.newsList.result = this.removeItem(this.newsList.result,articleId,category, cancelType)
    }else if(category === 'colleague') {
      this.topicList.result = this.removeItem(this.topicList.result,articleId,category, cancelType)
    }
  }
  @action cancelCmsFavorite = (articleId, cancelType, category) => {
    if(category === 'all'){
      this.allList.result = this.removeItem(this.allList.result,articleId,category, cancelType)
    }else if(category === 'message') {
      this.messageList.result = this.removeItem(this.messageList.result,articleId,category, cancelType)
    }else if(category === 'news') {
      this.newsList.result = this.removeItem(this.newsList.result,articleId,category, cancelType)
    }else if(category === 'colleague') {
      this.topicList.result = this.removeItem(this.topicList.result,articleId,category, cancelType)
    }
  }
  removeItem = (arr, id, type, cancelType) => {
    let data = {}
    if(type === 'message') {
      data = arr.filter(function(item){
        return item.id == id
      })
    }else if(type === 'colleague') {
      data = arr.filter(function(item){
        return item.sesFavoriteQuanTopicInfo.quanTopicId == id
      })
    }else if(type === 'news'){
      data = arr.filter(function(item){
        return item.sesFavoriteCmsInfo.articleId == id
      })
    }else if(type === 'all'){
      if(cancelType === 'im') {
        data = arr.filter(function(item){
          return item.id == id
        })
      }else if(cancelType === 'quan_topic') {
        data = arr.filter(function(item){
          if(item.sesFavoriteQuanTopicInfo){
            return item.sesFavoriteQuanTopicInfo.quanTopicId == id
          }
        })
      }else if(cancelType === 'cms'){
        data = arr.filter(function(item){
          if(item.sesFavoriteCmsInfo){
            return item.sesFavoriteCmsInfo.articleId == id
          }
        })
      }
    }
    arr.remove(data[0])
    return arr
  }
}

export default new UCFavorite()

==> kara-uc-1.1.93.tgz: package/src/kara-uc/stores/UCFavoriteStore.js <==
import {observable, action, extendObservable} from 'mobx'


class UCFavorite {
  @observable imgType = ['jpeg', 'gif', 'png', 'jpg', 'bmp']
  @observable favoriteList = 1
  @observable activeTab = 0
  @observable allList ={
    pageSize: 10,
    pageNo: 1,
    result: []
  }
  @observable topicList ={
    pageSize: 10,
    pageNo: 1,
    result: []
  }
  @observable newsList ={
    pageSize: 10,
    pageNo: 1,
    result: []
  }
  @observable messageList ={
    pageSize: 10,
    pageNo: 1,
    result: []
  }
  @observable imgViewList = []


  @action setActiveTab = index => {
    this.activeTab = index
    this.allList ={
      pageSize: 10,
      pageNo: 1,
      result: []
    }
    this.newsList = {
      pageSize: 10,
      pageNo: 1,
      result: []
    }
    this.messageList ={
      pageSize: 10,
      pageNo: 1,
      result: []
    }
    this.topicList ={
      pageSize: 10,
      pageNo: 1,
      result: []
    }
  }
  // @action downLoadFile = (url,fileName) => {
  //   httpAgent.Favorite.downLoadFile(url).then(action(
  //     res => {
  //       saveAs(res, decodeURI(fileName));
  //     }
  //   ))
  // }
  @action getAllList = (res, pageNo) => {
    if(pageNo === 1) {
      this.allList.result = []
    }
    this.allList.pageNo = res.pageInfo.pageNo
    this.allList.pageSize = res.pageInfo.pageSize
    this.allList.pageCount = res.pageInfo.pageCount
    this.allList.result = this.allList.result.concat(res.pageInfo.result)
    res.pageInfo.result.map((i)=>{
      if (this.imgType.includes(i.fileType)) {
        this.imgViewList.push(i)
      }
    })
  }

  @action getTopicList = (res, pageNo) => {
    if(res && res.resultCode && res.resultCode === '000000') {
      if(pageNo === 1) {
        this.topicList.result = []
      }
      this.topicList.pageNo = res.pageInfo.pageNo
      this.topicList.pageSize = res.pageInfo.pageSize
      this.topicList.pageCount = res.pageInfo.pageCount
      this.topicList.result = this.topicList.result.concat(res.pageInfo.result)
    }
  }

  @action getNewsList = (res,pageNo) => {
    if(pageNo === 1) {
      this.newsList.result = []
    }
    this.newsList.pageNo = res.pageInfo.pageNo
    this.newsList.pageSize = res.pageInfo.pageSize
    this.newsList.pageCount = res.pageInfo.pageCount
    this.newsList.result = this.newsList.result.concat(res.pageInfo.result)
  }

  @action getMessageList = (res,pageNo) => {
    if(pageNo === 1) {
      this.messageList.result = []
    }
    this.messageList.pageNo = res.pageInfo.pageNo
    this.messageList.pageSize = res.pageInfo.pageSize
    this.messageList.pageCount = res.pageInfo.pageCount
    this.messageList.result = this.messageList.result.concat(res.pageInfo.result)
    res.pageInfo.result.map((i)=>{
      if (this.imgType.includes(i.fileType)) {
        this.imgViewList.push(i)
      }
    })
  }
  @action cancelImFavorite = (articleId, cancelType, category) => {
    if(category === 'all'){
      this.allList.result = this.removeItem(this.allList.result,articleId,category, cancelType)
    }else if(category === 'message') {
      this.messageList.result = this.removeItem(this.messageList.result,articleId,category, cancelType)
    }else if(category === 'news') {
      this.newsList.result = this.removeItem(this.newsList.result,articleId,category, cancelType)
    }else if(category === 'colleague') {
      this.topicList.result = this.removeItem(this.topicList.result,articleId,category, cancelType)
    }
  }
  @action cancelCmsFavorite = (articleId, cancelType, category) => {
    if(category === 'all'){
      this.allList.result = this.removeItem(this.allList.result,articleId,category, cancelType)
    }else if(category === 'message') {
      this.messageList.result = this.removeItem(this.messageList.result,articleId,category, cancelType)
    }else if(category === 'news') {
      this.newsList.result = this.removeItem(this.newsList.result,articleId,category, cancelType)
    }else if(category === 'colleague') {
      this.topicList.result = this.removeItem(this.topicList.result,articleId,category, cancelType)
    }
  }
  removeItem = (arr, id, type, cancelType) => {
    let itemIdx = -1;
    const itemList = arr.slice()
    if(type === 'message') {
        itemIdx = itemList.findIndex(function(item){
        return item.id === id
      })
    }else if(type === 'colleague') {
        itemIdx = itemList.findIndex(function(item){
        return item.sesFavoriteQuanTopicInfo.quanTopicId === id
      })
    }else if(type === 'news'){
        itemIdx = itemList.findIndex(function(item){
        return item.sesFavoriteCmsInfo.articleId === id
      })
    }else if(type === 'all'){
      if(cancelType === 'im') {
          itemIdx = itemList.findIndex(function(item){
          return item.id === id
        })
      }else if(cancelType === 'quan_topic') {
          itemIdx = itemList.findIndex(function(item){
          if(item.sesFavoriteQuanTopicInfo){
            return item.sesFavoriteQuanTopicInfo.quanTopicId === id
          }
        })
      }else if(cancelType === 'cms'){
          itemIdx = itemList.findIndex(function(item){
          if(item.sesFavoriteCmsInfo){
            return item.sesFavoriteCmsInfo.articleId === id
          }
        })
      }
    }
    if (itemIdx >= 0) {
        extendObservable(itemList[itemIdx], {
            canceled: true
        });
        arr.replace(itemList)
    }
    return arr
  }
}

export default new UCFavorite()
